NAME
Evo::Lib::Net
VERSION
version 0.0214
net_gen_saddr_family
Takes ip and port and returns saddr and family. saddr can be used to bind, family to call socket
net_parse
Parse string address and return naddr and AF_INET or AF_INET6. If address isn't valid ipv4|6, return empty list
net_smart_unpack
returns address as string and port from the saddr structure. Die if addres isn't IVp6 or IPv4
AUTHOR
alexbyk.com
COPYRIGHT AND LICENSE
This software is copyright (c) 2016 by alexbyk.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.